==> lt-2.5.zip: lt/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Į turinį';
$GLOBALS['__l10n']['To menu'] = 'Į meniu';
$GLOBALS['__l10n']['To search'] = 'Į paiešką';
$GLOBALS['__l10n']['By'] = 'Įrašė';
$GLOBALS['__l10n']['by'] = 'įrašė';
$GLOBALS['__l10n']['on'] = ',';
$GLOBALS['__l10n']['On'] = ',';
$GLOBALS['__l10n']['Continue reading'] = 'Skaityti toliau';
$GLOBALS['__l10n']['no comment'] = 'komentarų nėra';
$GLOBALS['__l10n']['one comment'] = 'vienas komentaras';
$GLOBALS['__l10n']['%d comments'] = '%d komentarai';
$GLOBALS['__l10n']['no trackback'] = 'trackback nėra';
$GLOBALS['__l10n']['one trackback'] = 'vienas trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback';
$GLOBALS['__l10n']['no attachment'] = 'prisegimų nėra';
$GLOBALS['__l10n']['one attachment'] = 'vienas prisegimas';
$GLOBALS['__l10n']['%d attachments'] = '%d prisegimai';
$GLOBALS['__l10n']['previous entries'] = 'ankstesni įrašai';
$GLOBALS['__l10n']['page'] = 'puslapis';
$GLOBALS['__l10n']['of'] = 'iš';
$GLOBALS['__l10n']['next entries'] = 'sekantys įrašai';
$GLOBALS['__l10n']['Search'] = 'Paieška';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Jūsų <em>%1$s</em> paieška nieko nerado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Jūsų <em>%1$s</em> paieška atitiko <strong>%2$s</strong> įrašą.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Jūsų <em>%1$s</em> paieška atitiko <strong>%2$s</strong> įrašus.';
$GLOBALS['__l10n']['Home'] = 'Pradžia';
$GLOBALS['__l10n']['All keywords'] = 'Visi raktažodžiai';
$GLOBALS['__l10n']['Best of me'] = 'Mano geriausia';
$GLOBALS['__l10n']['Languages'] = 'Kalbos';
$GLOBALS['__l10n']['Categories'] = 'Kategorijos';
$GLOBALS['__l10n']['Subcategories'] = 'Subkategorijos';
$GLOBALS['__l10n']['Archives'] = 'Archyvai';
$GLOBALS['__l10n']['Links'] = 'Nuorodos';
$GLOBALS['__l10n']['Subscribe'] = 'Prenumeruoti';
$GLOBALS['__l10n']['Entries feed'] = 'Įrašų rss feed';
$GLOBALS['__l10n']['Comments feed'] = 'Komentarų rss feed';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Šio blogo komentarų Atom feed';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Šios kategorijos įrašų Atom feed';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Šios kategorijos komentarų Atom feed';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Šios įrašo komentarų rss feed';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Šios įrašo komentarų Atom feed';
$GLOBALS['__l10n']['Attachments'] = 'Prisegimai';
$GLOBALS['__l10n']['Permalink'] = 'nuoroda';
$GLOBALS['__l10n']['Comments'] = 'Komentarai';
$GLOBALS['__l10n']['Your comment'] = 'Jūsų komentaras';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Jūsų komentaras paskelbtas.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Jūsų komentaras priimtas ir bus peržiūrėtas prieš skelbiant.';
$GLOBALS['__l10n']['Add a comment'] = 'Pridėti komentarą';
$GLOBALS['__l10n']['Name or nickname'] = 'Vardas ar slapyvardis';
$GLOBALS['__l10n']['Email address'] = 'El. pašto adresas';
$GLOBALS['__l10n']['Website'] = 'Tinklapis';
$GLOBALS['__l10n']['optional'] = 'pasirinktinai';
$GLOBALS['__l10n']['Comment'] = 'Komentaras';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML kodas yra rodomas kaip tekstas ir internetiniai adresai yra automatiškai konvertuojami.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Prisiminti mane šiame bloge';
$GLOBALS['__l10n']['preview'] = 'peržiūrėti';
$GLOBALS['__l10n']['send'] = 'siųsti';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Jie parašė ta pačia tema';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Turite nurodyti autoriaus vardą';
$GLOBALS['__l10n']['You must provide a comment'] = 'Turite parašyti komentarą';
$GLOBALS['__l10n']['Email address is not valid'] = 'El. pašto adresas netinkamas';
$GLOBALS['__l10n']['Document not found'] = 'Dokumentas nerastas';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Dokumentas kurio ieškote neegzistuoja';
$GLOBALS['__l10n']['Powered by %s'] = 'bogą gamina %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Prenumeruoti';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Kas yra RSS feed?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS yra nemokama interneto naujienų suvestinė. RSS pateikiamos naujienos ar naujienų komentarai, kartu su nuorodomis į pilną turinį ir kita. Tokiu būdu naujausius publikuotus įrašus tuomet galite perskaityti savo pasirinkta <a href="http://en.wikipedia.org/wiki/Aggregator">priemone</a>.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Paprasčiausiai nukopijuokite URL nuorodą į savo RSS programą.';
$GLOBALS['__l10n']['Password needed'] = 'Reikalingas slaptažodis';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Norėdami čia apsilankyti turite nurodyti slaptažodį.';
$GLOBALS['__l10n']['Password:'] = 'Slaptažodis:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Turite nurodyti teisingą el. pašto adresą.';
$GLOBALS['__l10n']['Read'] = 'Skaityti';
?>

==> lt-2.5.1.zip: lt/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'Į turinį';
$GLOBALS['__l10n']['To menu'] = 'Į meniu';
$GLOBALS['__l10n']['To search'] = 'Į paiešką';
$GLOBALS['__l10n']['By'] = 'Įrašė';
$GLOBALS['__l10n']['by'] = 'įrašė';
$GLOBALS['__l10n']['on'] = ', ';
$GLOBALS['__l10n']['On'] = ', ';
$GLOBALS['__l10n']['Continue reading'] = 'Skaityti toliau';
$GLOBALS['__l10n']['no comment'] = 'komentarų nėra';
$GLOBALS['__l10n']['one comment'] = 'vienas komentaras';
$GLOBALS['__l10n']['%d comments'] = '%d komentarai';
$GLOBALS['__l10n']['no trackback'] = 'trackback nėra';
$GLOBALS['__l10n']['one trackback'] = 'vienas trackback';
$GLOBALS['__l10n']['%d trackbacks'] = '%d trackback';
$GLOBALS['__l10n']['no attachment'] = 'prisegimų nėra';
$GLOBALS['__l10n']['one attachment'] = 'vienas prisegimas';
$GLOBALS['__l10n']['%d attachments'] = '%d prisegimai';
$GLOBALS['__l10n']['previous entries'] = 'ankstesni įrašai';
$GLOBALS['__l10n']['page'] = 'puslapis';
$GLOBALS['__l10n']['of'] = 'iš';
$GLOBALS['__l10n']['next entries'] = 'sekantys įrašai';
$GLOBALS['__l10n']['Search'] = 'Paieška';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = 'Jūsų <em>%1$s</em> paieška nieko nerado.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Jūsų <em>%1$s</em> paieška atitiko <strong>%2$s</strong> įrašą.';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Jūsų <em>%1$s</em> paieška atitiko <strong>%2$s</strong> įrašus.';
$GLOBALS['__l10n']['Home'] = 'Pradžia';
$GLOBALS['__l10n']['All keywords'] = 'Visi raktažodžiai';
$GLOBALS['__l10n']['Best of me'] = 'Mano geriausia';
$GLOBALS['__l10n']['Languages'] = 'Kalbos';
$GLOBALS['__l10n']['Categories'] = 'Kategorijos';
$GLOBALS['__l10n']['Subcategories'] = 'Subkategorijos';
$GLOBALS['__l10n']['Archives'] = 'Archyvai';
$GLOBALS['__l10n']['Links'] = 'Nuorodos';
$GLOBALS['__l10n']['Subscribe'] = 'Prenumeruoti';
$GLOBALS['__l10n']['Entries feed'] = 'Įrašų rss feed';
$GLOBALS['__l10n']['Comments feed'] = 'Komentarų rss feed';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'Šio blogo komentarų Atom feed';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'Šios kategorijos įrašų Atom feed';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'Šios kategorijos komentarų Atom feed';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'Šios įrašo komentarų rss feed';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'Šios įrašo komentarų Atom feed';
$GLOBALS['__l10n']['Attachments'] = 'Prisegimai';
$GLOBALS['__l10n']['Permalink'] = 'nuoroda';
$GLOBALS['__l10n']['Comments'] = 'Komentarai';
$GLOBALS['__l10n']['Your comment'] = 'Jūsų komentaras';
$GLOBALS['__l10n']['Your comment has been published.'] = 'Jūsų komentaras paskelbtas.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'Jūsų komentaras priimtas ir bus peržiūrėtas prieš skelbiant.';
$GLOBALS['__l10n']['Add a comment'] = 'Pridėti komentarą';
$GLOBALS['__l10n']['Name or nickname'] = 'Vardas ar slapyvardis';
$GLOBALS['__l10n']['Email address'] = 'El. pašto adresas';
$GLOBALS['__l10n']['Website'] = 'Tinklapis';
$GLOBALS['__l10n']['optional'] = 'pasirinktinai';
$GLOBALS['__l10n']['Comment'] = 'Komentaras';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML kodas yra rodomas kaip tekstas ir internetiniai adresai yra automatiškai konvertuojami.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'Prisiminti mane šiame bloge';
$GLOBALS['__l10n']['preview'] = 'peržiūrėti';
$GLOBALS['__l10n']['send'] = 'siųsti';
$GLOBALS['__l10n']['They posted on the same topic'] = 'Jie parašė ta pačia tema';
$GLOBALS['__l10n']['Trackback URL'] = 'Trackback URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'Turite nurodyti autoriaus vardą';
$GLOBALS['__l10n']['You must provide a comment'] = 'Turite parašyti komentarą';
$GLOBALS['__l10n']['Email address is not valid'] = 'El. pašto adresas netinkamas';
$GLOBALS['__l10n']['Document not found'] = 'Dokumentas nerastas';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'Dokumentas kurio ieškote neegzistuoja';
$GLOBALS['__l10n']['Powered by %s'] = 'bogą gamina %s';
$GLOBALS['__l10n']['Subscribe to'] = 'Prenumeruoti';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'Kas yra RSS feed?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS yra nemokama interneto naujienų suvestinė. RSS pateikiamos naujienos ar naujienų komentarai, kartu su nuorodomis į pilną turinį ir kita. Tokiu būdu naujausius publikuotus įrašus tuomet galite perskaityti savo pasirinkta <a href="http://en.wikipedia.org/wiki/Aggregator">priemone</a>.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'Paprasčiausiai nukopijuokite URL nuorodą į savo RSS programą.';
$GLOBALS['__l10n']['Password needed'] = 'Reikalingas slaptažodis';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'Norėdami čia apsilankyti turite nurodyti slaptažodį.';
$GLOBALS['__l10n']['Password:'] = 'Slaptažodis:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'Turite nurodyti teisingą el. pašto adresą.';
$GLOBALS['__l10n']['Read'] = 'Skaityti';
?>
